@@ -10,11 +10,11 @@ import publication
 
 import aws_cdk.aws_iam
 import aws_cdk.aws_kms
+import aws_cdk.cloud_assembly_schema
 import aws_cdk.core
-import aws_cdk.cx_api
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ssm", "1.36.1", __name__[0:-6], "aws-ssm@1.36.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ssm", "1.38.0", __name__[0:-6], "aws-ssm@1.38.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
